import React, { useRef } from 'react'
import moment from 'moment';
import { DatePicker, Button } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable'
import { getApplicationList } from '@/services/application'

const { RangePicker } = DatePicker;

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};

export default (props) => {
  const actionRef = useRef();
  const columns = [
    {
      title: '申请人',
      dataIndex: 'personName',
      key: 'personName',
      search: true,
    },
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t) => formatterTime(t),
      renderFormItem: (_, record) => <RangePicker format='YYYY-MM-DD' />
    },
    {
      title: '订单状态',
      dataIndex: 'status',
      key: 'status',
      search: true,//已支付 待支付
    },
    {
      title: '审核状态',
      dataIndex: 'verifyStatus',
      key: 'verifyStatus',
      search: true,
    },
    {
      title: '操作',
      valueType: 'option',
      width: 160,
      render: (_, record) => [
        <Button key={1} style={{ padding: 0 }} type="link">
          详情
        </Button>
      ],
    },
  ]


  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={actionRef}
        columns={columns}
        request={getApplicationList}
        options={false}
        rowKey="applyId"
      />
    </PageHeaderWrapper>
  )
}
