import React, { useRef } from 'react'
import { useModel } from 'umi';
import moment from 'moment';
import { DatePicker, Button } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable'
import { getList } from '@/services/work'

const { RangePicker } = DatePicker;

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};

export default (props) => {
  const initDate = useRef(moment())
  const actionRef = useRef();
  const { initialState } = useModel('@@initialState');

  const handleBeforSearch = (params) => {
    const { createDate, ...others } = params;

    let start, end, orgId;
    if (!createDate || createDate.length < 1) {
      // 默认时间是今天
      start = moment().format('YYYY-MM-DD')
      end = start
    } else {
      start = moment(createDate[0]).format('YYYY-MM-DD')
      end = moment(createDate[1]).format('YYYY-MM-DD')
    }
    if (initialState.currentUser.orgId) {
      orgId = initialState.currentUser.orgId
      return { ...others, start, end, orgId };
    }
    return { ...others, start, end };
  }
  const columns = [
    {
      title: '申请人',
      dataIndex: 'userName',
      key: 'userName',
      search: true,
    },
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t) => formatterTime(t),
      renderFormItem: (_, record) => <RangePicker defaultValue={[initDate.current, initDate.current]} placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' />
    },
    {
      title: '审核状态',
      dataIndex: 'userName',
      key: 'userName',
      search: true,
    },
    {
      title: '审核人',
      dataIndex: 'userName',
      key: 'userName',
      search: true,
    },
    {
      title: '审核时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t) => formatterTime(t),
      renderFormItem: (_, record) => <RangePicker defaultValue={[initDate.current, initDate.current]} placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' />
    },
    {
      title: '操作',
      valueType: 'option',
      width: 160,
      render: (_, record) => [
        <Button key={1} style={{ padding: 0 }} type="link">
          详情
        </Button>
      ],
    },
  ]


  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={actionRef}
        columns={columns}
        request={getList}
        options={false}
        search={{
          defaultCollapsed: false
        }}
        form={{ ignoreRules: false }}
        manualRequest={true}
        revalidateOnFocus={false}
        beforeSearchSubmit={handleBeforSearch}
        rowKey="formId"
      />
    </PageHeaderWrapper>
  )
}
